@@ -11,7 +11,7 @@ import platform
 from time import sleep
 import logging
 
-from IPython.nbformat.current import read, write, NotebookNode
+from IPython.nbformat.current import NotebookNode
 from IPython.kernel import KernelManager
 
 
@@ -31,9 +31,11 @@ class NotebookRunner(object):
         'text/html': 'html',
         'text/latex': 'latex',
         'application/javascript': 'html',
+        'image/svg+xml': 'svg',
     }
 
-    def __init__(self, nb_in, pylab=False, mpl_inline=False):
+
+    def __init__(self, nb, pylab=False, mpl_inline=False):
         self.km = KernelManager()
         if pylab:
             self.km.start_kernel(extra_arguments=['--pylab=inline'])
@@ -55,14 +57,15 @@ class NotebookRunner(object):
 
         self.shell = self.kc.shell_channel
         self.iopub = self.kc.iopub_channel
-
-        logging.info('Reading notebook %s', nb_in)
-        self.nb = read(open(nb_in), 'json')
+        
+        self.nb = nb
+        
 
     def __del__(self):
         self.kc.stop_channels()
         self.km.shutdown_kernel(now=True)
 
+
     def run_cell(self, cell):
         '''
         Run a notebook cell and update the output of that cell in-place.
@@ -126,6 +129,7 @@ class NotebookRunner(object):
         if status == 'error':
             raise NotebookError()
 
+
     def iter_code_cells(self):
         '''
         Iterate over the notebook cells containing code.
@@ -151,7 +155,3 @@ class NotebookRunner(object):
                 if not skip_exceptions:
                     raise
 
-    def save_notebook(self, nb_out):
-        logging.info('Saving to %s', nb_out)
-        write(self.nb, open(nb_out, 'w'), 'json')
-
